==> browser-js-env-0.0.3.tgz: package/src/server.js <==
'use strict';

let crudeServer = require('crude-server');
let path = require('path');
let {
    createReadStream
} = require('fs');

module.exports = ({
    testDir,
    reportPath = '/__api/__reportData'
}) => {
    let indexHTML = path.join(testDir, 'index.html');
    let appHTML = path.join(testDir, 'asset/app.js');

    let receiveHandler = null;

    let setReceiveHandler = (handler) => {
        receiveHandler = handler;
    };

    let {
        start, stop
    } = crudeServer((pathname) => {
        if (pathname === '/index.html') {
            return (req, res) => {
                res.setHeader('Content-Type', 'text/html; charset=utf-8');
                createReadStream(indexHTML).pipe(res);
            };
        } else if (pathname === '/asset/app.js') {
            return (req, res) => {
                res.setHeader('Content-Type', 'application/javascript');
                createReadStream(appHTML).pipe(res);
            };
        } else if (pathname === reportPath) {
            return (req, res) => {
                let str = '';
                req.on('data', (chunk) => {
                    str += chunk.toString();
                });

                req.on('end', () => {
                    let data = JSON.parse(str);

                    res.end(JSON.stringify({
                        errNo: 0
                    }));

                    stop().then(() => {
                        receiveHandler && receiveHandler(data);
                    });
                });
            };
        }
    });

    return {
        start, setReceiveHandler
    };
};

==> browser-js-env-0.0.4.tgz: package/src/server.js <==
'use strict';

let crudeServer = require('crude-server');
let path = require('path');
let mime = require('mime-types');
let {
    createReadStream
} = require('fs');

module.exports = ({
    testDir,
    reportPath = '/__api/__reportData', logPath = '/__api/__log'
}) => {
    let receiveHandler = null;

    let setReceiveHandler = (handler) => {
        receiveHandler = handler;
    };

    let {
        start, stop
    } = crudeServer((pathname) => {
        if (pathname === reportPath) {
            return (req, res) => {
                let str = '';
                req.on('data', (chunk) => {
                    str += chunk.toString();
                });

                req.on('end', () => {
                    let data = JSON.parse(str);

                    res.end(JSON.stringify({
                        errNo: 0
                    }));

                    stop().then(() => {
                        receiveHandler && receiveHandler(data);
                    });
                });
            };
        } else if (pathname === logPath) {
            return (req, res) => {
                let str = '';
                req.on('data', (chunk) => {
                    str += chunk.toString();
                });

                req.on('end', () => {
                    let args = JSON.parse(str);

                    res.end(JSON.stringify({
                        errNo: 0
                    }));

                    console.log(...args); // eslint-disable-line
                });
            };
        } else {
            return (req, res) => { // just pipe static file
                res.setHeader('Content-Type', mime.lookup(pathname));
                createReadStream(path.join(testDir, pathname.substring(1))).pipe(res);
            };
        }
    });

    return {
        start, setReceiveHandler
    };
};
